function [gain phase] = find_gain_phase_abs( data, frequency, filter_cutoff )
  % find the gain and phase relationship of abs(command) (3) and velocity (from position (2)), when velocity is actually the absolute value of velocity. Low pass filter both commands and velocity with the same filter

% constants
Ts = 0.005; % sampling interval
[b,a] = butter(1,filter_cutoff);  % low pass filter 

% get filtered absolute value of velocity
abs_positionf = filtfilt(b,a,data(:,2));
abs_velocityf = diff(abs_positionf);
% number of points in data
N = length(abs_velocityf);

% get filtered absolute value of command
temp = filtfilt(b,a,abs(data(:,3)));
abs_commandsf = temp(2:(N+1));

% compute period in samples
period = 1/(Ts*frequency);

% check out fits over an entire period.

start = 1;
n_points = N;
min_score = 1e10;
if frequency < 2 % stiction at low frequencies
  max_shift = round((0.9*period)/2);
else
  max_shift = round(period/2);
end

for i = 1:max_shift;
  [p,conf_intervals,residuals] = regress(abs_velocityf(start:(start+n_points-1)),abs_commandsf(1:n_points));
  score = 0;
  for j = 1:n_points
    score = score + residuals(j)*residuals(j);
  end
  score = score/length(residuals);
  if score < min_score
    min_score = score;
    min_i = i;
    min_p = p;
  end
  start = start+1;
  n_points = n_points-1;
end

gain = min_p;
phase = min_i/period;
[frequency gain phase]

start = 20;
n_points = 5*period;
if n_points > N - min_i - start
   n_points = N - min_i - start;
end

figure(1);
plot( abs_commandsf(start:round(start+n_points-1)), 'b' );
hold;
plot( abs_velocityf(start+min_i-1:round(start+min_i+n_points-2))/gain, 'r' );
hold;

%pause(5);
